import React, { useEffect, useState } from 'react';
import ReactDOM from 'react-dom/client';
import { BrowserRouter, Routes, Route, Navigate } from 'react-router-dom';
import App from './App';
import './index.css';

// Admin components
import { AuthProvider } from './admin/utils/authContext';
import ProtectedRoute from './admin/components/ProtectedRoute';
import AdminLayout from './admin/components/AdminLayout';
import Login from './admin/pages/Login';
import Dashboard from './admin/pages/Dashboard';
import ContentManager from './admin/pages/ContentManager';
import Appearance from './admin/pages/Appearance';
import Settings from './admin/pages/Settings';

// Setup components
import SetupPage from './setup/SetupPage';
import { isSetupComplete } from './setup/utils';

// Setup checker component
const SetupChecker: React.FC<{ children: React.ReactNode }> = ({ children }) => {
  const [loading, setLoading] = useState(true);
  const [setupNeeded, setSetupNeeded] = useState(false);

  useEffect(() => {
    // Check if installation is complete
    // In a real app, this would call an API
    const setupComplete = isSetupComplete();
    setSetupNeeded(!setupComplete);
    setLoading(false);
  }, []);

  if (loading) {
    // Show a loading spinner while checking
    return (
      <div className="min-h-screen flex items-center justify-center bg-primary">
        <div className="text-white text-center">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-white mx-auto mb-4" />
          <p>Loading site...</p>
        </div>
      </div>
    );
  }

  // If setup is needed, redirect to setup
  if (setupNeeded && window.location.pathname !== '/setup') {
    return <Navigate to="/setup" replace />;
  }

  // If we're at /setup but already installed, redirect to home
  if (!setupNeeded && window.location.pathname === '/setup') {
    return <Navigate to="/" replace />;
  }

  return <>{children}</>;
};

// Get the root element
const rootElement = document.getElementById('root');
if (!rootElement) {
  throw new Error('Failed to find root element');
}

ReactDOM.createRoot(rootElement).render(
  <React.StrictMode>
    <BrowserRouter>
      <AuthProvider>
        <SetupChecker>
          <Routes>
            {/* Setup route */}
            <Route path="/setup" element={<SetupPage />} />

            {/* Main website routes */}
            <Route path="/" element={<App />} />

            {/* Admin routes */}
            <Route path="/admin/login" element={<Login />} />
            <Route
              path="/admin"
              element={
                <ProtectedRoute>
                  <AdminLayout />
                </ProtectedRoute>
              }
            >
              <Route path="dashboard" element={<Dashboard />} />
              <Route path="content" element={<ContentManager />} />
              <Route path="appearance" element={<Appearance />} />
              <Route path="settings" element={<Settings />} />
              <Route index element={<Dashboard />} />
            </Route>

            {/* Fallback route */}
            <Route path="*" element={<App />} />
          </Routes>
        </SetupChecker>
      </AuthProvider>
    </BrowserRouter>
  </React.StrictMode>
);
